@@ -10,7 +10,7 @@ BEGIN
 	use Carp;
 	use vars  qw( $VERSION $lcnt_max $ssec );
 
-	$VERSION = "3.02";
+	$VERSION = "3.03";
 }
 
 
@@ -1095,7 +1095,7 @@ __END__
 
 =head1 NAME
 
- Parse::Plain - template parsing engine (version 3.02)
+ Parse::Plain - template parsing engine (version 3.03)
 
 
 =head1 SYNOPSIS
@@ -1203,7 +1203,7 @@ this document. To illustrate the difference:
 
 =head2 new
 
-The constructor. The first parameter (mandatiry) is a path to template
+The constructor. The first parameter (mandatory) is a path to template
 file. Template file must exist and be readable. If file cannot be read
 several attempts will be made (by default 5 attemts with 1 second interval
 between attemts). You can optionally change these values by passing
@@ -1528,7 +1528,7 @@ o
 
 One will be parsed to
 
-      Hello
+       Hello
 
 line. However since version 3.00 you could also use such template:
 
@@ -1544,7 +1544,7 @@ You may not use colons in callback tagnames.
 
 =item *
 Obviously, it's not a very good idea to use this module for 
-binary templates. :-)
+binary templates. ;-)
 
 =back
 
